package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.AssignVirtualaccountInput;
import com.gmo_pg.g_pay.client.output.AssignVirtualaccountOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * 銀行振込(バーチャル口座)継続口座登録呼出サーブレットサンプルクラス
 */
public class CallAssignVirtualaccountServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_RESERVE_ID = "ReserveID";
	private static final String P_BANK_CODE = "BankCode";
	private static final String P_BRANCH_CODE = "BranchCode";
	private static final String P_ACCOUNT_TYPE = "AccountType";
	private static final String P_ACCOUNT_NUMBER = "AccountNumber";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        AssignVirtualaccountInput input = new AssignVirtualaccountInput();
        AssignVirtualaccountOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setReserveID(req.getParameter(P_RESERVE_ID));
		input.setBankCode(req.getParameter(P_BANK_CODE));
		input.setBranchCode(req.getParameter(P_BRANCH_CODE));
		input.setAccountType(req.getParameter(P_ACCOUNT_TYPE));
		input.setAccountNumber(req.getParameter(P_ACCOUNT_NUMBER));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doAssignVirtualaccount(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "ReserveID: {0}", output.getReserveID());
			print(out, "BankCode: {0}", output.getBankCode());
			print(out, "BankName: {0}", output.getBankName());
			print(out, "BranchCode: {0}", output.getBranchCode());
			print(out, "BranchName: {0}", output.getBranchName());
			print(out, "AccountType: {0}", output.getAccountType());
			print(out, "AccountNumber: {0}", output.getAccountNumber());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
