package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.AuSalesInput;
import java.util.Iterator;
import java.util.List;
import com.gmo_pg.g_pay.client.output.AuSalesOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;


/**
 * auかんたん決済売上確定呼出サーブレットサンプルクラス
 */
public class CallAuSalesServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ACCESS_ID = "AccessID";
	private static final String P_ACCESS_PASS = "AccessPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_AMOUNT = "Amount";
	private static final String P_TAX = "Tax";

	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        AuSalesInput input = new AuSalesInput();
        AuSalesOutput output = null;

        // パラメータの設定
        input.setShopID(req.getParameter(P_SHOP_ID));
        input.setShopPass(req.getParameter(P_SHOP_PASS));
        input.setAccessID(req.getParameter(P_ACCESS_ID));
        input.setAccessPass(req.getParameter(P_ACCESS_PASS));
        input.setOrderID(req.getParameter(P_ORDER_ID));
        input.setAmount(
        		req.getParameter(P_AMOUNT) == null
        			? null : Integer.valueOf(req.getParameter(P_AMOUNT)));
        input.setTax(
        		req.getParameter(P_TAX) == null
        			? null : Integer.valueOf(req.getParameter(P_TAX)));
       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doAuSales(input);
		} catch (PaymentException e) {
			//
			// [注意事項]
			// エラーが発生した場合は、お手数ですが加盟店様側でエラー処理を行っていただくようお願い致します。
			//
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
        if (output.isErrorOccurred()) {
        	List list = output.getErrList();
    		print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
        		print(out, "ErrorCode: {0}  ErrorInfo: {1}",
        				new Object[]{eh.getErrCode(), eh.getErrInfo()});

        	}
        } else {
    		print(out, "OUTPUT:");
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "Status: {0}", output.getStatus());
			print(out, "Amount: {0}", output.getAmount());
			print(out, "Tax: {0}", output.getTax());
		}
        out.flush();
    }

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
