package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.BookSalesProcessInput;
import com.gmo_pg.g_pay.client.output.BookSalesProcessOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;

/**
 * 実売予約呼出サーブレットサンプルクラス
 */
public class CallBookSalesProcessServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ACCESS_ID = "AccessID";
	private static final String P_ACCESS_PASS = "AccessPass";
	private static final String P_BOOKING_DATE = "BookingDate";
	private static final String P_AMOUNT = "Amount";

	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {

		req.setCharacterEncoding("windows-31j");
		res.setContentType("text/html; charset=windows-31j");
		PrintWriter out = res.getWriter();

		PaymentClientImpl client = new PaymentClientImpl();
		BookSalesProcessInput input = new BookSalesProcessInput();
		BookSalesProcessOutput output = null;

		// パラメータの設定
		input.setShopId(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setAccessId(req.getParameter(P_ACCESS_ID));
		input.setAccessPass(req.getParameter(P_ACCESS_PASS));
		input.setBookingDate(req.getParameter(P_BOOKING_DATE));
		input.setAmount(req.getParameter(P_AMOUNT) == null ? null : Integer
				.valueOf(req.getParameter(P_AMOUNT)));
		print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doBookSalesProcess(input);
		} catch (PaymentException e) {
			//
			// [注意事項]
			// エラーが発生した場合は、お手数ですが加盟店様側でエラー処理を行っていただくようお願い致します。
			//
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for (Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder) it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[] { eh.getErrCode(), eh.getErrInfo() });

			}
		} else {
			print(out, "OUTPUT:");
			print(out, "AccessID: {0}", output.getAccessId());
			print(out, "AccessPass: {0}", output.getAccessPass());
			print(out, "BookingInfoVersion: {0}",
					output.getBookingInfoVersion());
		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[] { obj });
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt, obj));
		out.print(MessageFormat.format(fmt, obj));
		out.print("<br>");
		out.println();
	}
}
