package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.ChangeRecurringSelectInput;
import com.gmo_pg.g_pay.client.output.ChangeRecurringSelectOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * 自動売上自動売上定義変更(口座振替セレクト)呼出サーブレットサンプルクラス
 */
public class CallChangeRecurringSelectServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_RECURRING_ID = "RecurringID";
	private static final String P_PLAN_ID = "PlanID";
	private static final String P_AMOUNT = "Amount";
	private static final String P_TAX = "Tax";
	private static final String P_CHARGE_MONTH = "ChargeMonth";
	private static final String P_CHARGE_DAY = "ChargeDay";
	private static final String P_CHARGE_STOP_DATE = "ChargeStopDate";
	private static final String P_UPDATE_TYPE = "UpdateType";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        ChangeRecurringSelectInput input = new ChangeRecurringSelectInput();
        ChangeRecurringSelectOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setRecurringID(req.getParameter(P_RECURRING_ID));
		input.setPlanID(req.getParameter(P_PLAN_ID));
		input.setAmount(
				req.getParameter(P_AMOUNT) == null || req.getParameter(P_AMOUNT).length() == 0
					? null : new Integer(req.getParameter(P_AMOUNT)));

		input.setTax(
				req.getParameter(P_TAX) == null || req.getParameter(P_TAX).length() == 0
					? null : new Integer(req.getParameter(P_TAX)));

		input.setChargeMonth(req.getParameter(P_CHARGE_MONTH));
		input.setChargeDay(req.getParameter(P_CHARGE_DAY));
		input.setChargeStopDate(req.getParameter(P_CHARGE_STOP_DATE));
		input.setUpdateType(req.getParameter(P_UPDATE_TYPE));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doChangeRecurringSelect(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "ShopID: {0}", output.getShopID());
			print(out, "RecurringID: {0}", output.getRecurringID());
			print(out, "Amount: {0}", output.getAmount());
			print(out, "Tax: {0}", output.getTax());
			print(out, "ChargeMonth: {0}", output.getChargeMonth());
			print(out, "ChargeDay: {0}", output.getChargeDay());
			print(out, "ChargeStartDate: {0}", output.getChargeStartDate());
			print(out, "ChargeStopDate: {0}", output.getChargeStopDate());
			print(out, "NextChargeDate: {0}", output.getNextChargeDate());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
