package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.ChargePrecaInput;
import com.gmo_pg.g_pay.client.output.ChargePrecaOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;

import java.math.BigDecimal;

/**
 * PGプリカチャージ呼出サーブレットサンプルクラス
 */
public class CallChargePrecaServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_PRECA_NO = "PrecaNo";
	private static final String P_PRECA_PASS = "PrecaPass";
	private static final String P_AMOUNT = "Amount";
	private static final String P_CHARGE_TYPE = "ChargeType";
	private static final String P_CLIENT_FIELD = "ClientField";
	private static final String P_TD_FLAG = "TdFlag";
	private static final String P_TD_TENANT_NAME = "TdTenantName";
	private static final String P_RET_URL = "RetURL";
	private static final String P_AUTH_PROCESS_TERM_SEC = "AuthProcessTermSec";
	private static final String P_CARD_NO = "CardNo";
	private static final String P_EXPIRE = "Expire";
	private static final String P_SECURITY_CODE = "SecurityCode";
	private static final String P_TOKEN = "Token";
	private static final String P_SITE_ID = "SiteID";
	private static final String P_SITE_PASS = "SitePass";
	private static final String P_MEMBER_ID = "MemberID";
	private static final String P_SEQ_MODE = "SeqMode";
	private static final String P_CARD_SEQ = "CardSeq";
	private static final String P_CVS_CODE = "CvsCode";
	private static final String P_CUSTOMER_NAME = "CustomerName";
	private static final String P_CUSTOMER_KANA = "CustomerKana";
	private static final String P_TEL_NO = "TelNo";
	private static final String P_PAYMENT_TERM_DAY = "PaymentTermDay";
	private static final String P_RECEIPTS_DISP11 = "ReceiptsDisp11";
	private static final String P_RECEIPTS_DISP12 = "ReceiptsDisp12";
	private static final String P_RECEIPTS_DISP13 = "ReceiptsDisp13";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        ChargePrecaInput input = new ChargePrecaInput();
        ChargePrecaOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setOrderID(req.getParameter(P_ORDER_ID));
		input.setPrecaNo(req.getParameter(P_PRECA_NO));
		input.setPrecaPass(req.getParameter(P_PRECA_PASS));
		input.setAmount(
				req.getParameter(P_AMOUNT) == null || req.getParameter(P_AMOUNT).length() == 0
					? null : new BigDecimal(req.getParameter(P_AMOUNT)));

		input.setChargeType(req.getParameter(P_CHARGE_TYPE));
		input.setClientField(req.getParameter(P_CLIENT_FIELD));
		input.setTdFlag(req.getParameter(P_TD_FLAG));
		input.setTdTenantName(req.getParameter(P_TD_TENANT_NAME));
		input.setRetURL(req.getParameter(P_RET_URL));
		input.setAuthProcessTermSec(
				req.getParameter(P_AUTH_PROCESS_TERM_SEC) == null || req.getParameter(P_AUTH_PROCESS_TERM_SEC).length() == 0
					? null : new Integer(req.getParameter(P_AUTH_PROCESS_TERM_SEC)));

		input.setCardNo(req.getParameter(P_CARD_NO));
		input.setExpire(req.getParameter(P_EXPIRE));
		input.setSecurityCode(req.getParameter(P_SECURITY_CODE));
		input.setToken(req.getParameter(P_TOKEN));
		input.setSiteID(req.getParameter(P_SITE_ID));
		input.setSitePass(req.getParameter(P_SITE_PASS));
		input.setMemberID(req.getParameter(P_MEMBER_ID));
		input.setSeqMode(req.getParameter(P_SEQ_MODE));
		input.setCardSeq(req.getParameter(P_CARD_SEQ));
		input.setCvsCode(req.getParameter(P_CVS_CODE));
		input.setCustomerName(req.getParameter(P_CUSTOMER_NAME));
		input.setCustomerKana(req.getParameter(P_CUSTOMER_KANA));
		input.setTelNo(req.getParameter(P_TEL_NO));
		input.setPaymentTermDay(req.getParameter(P_PAYMENT_TERM_DAY));
		input.setReceiptsDisp11(req.getParameter(P_RECEIPTS_DISP11));
		input.setReceiptsDisp12(req.getParameter(P_RECEIPTS_DISP12));
		input.setReceiptsDisp13(req.getParameter(P_RECEIPTS_DISP13));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doChargePreca(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "AccessID: {0}", output.getAccessID());
			print(out, "AccessPass: {0}", output.getAccessPass());
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "Status: {0}", output.getStatus());
			print(out, "TranDate: {0}", output.getTranDate());
			print(out, "CheckString: {0}", output.getCheckString());
			print(out, "PrecaNo: {0}", output.getPrecaNo());
			print(out, "PrecaSeq: {0}", output.getPrecaSeq());
			print(out, "ExpireDate: {0}", output.getExpireDate());
			print(out, "ACS: {0}", output.getACS());
			print(out, "Forward: {0}", output.getForward());
			print(out, "Approve: {0}", output.getApprove());
			print(out, "AuthProcessingURL: {0}", output.getAuthProcessingURL());
			print(out, "AuthProcessingHash: {0}", output.getAuthProcessingHash());
			print(out, "CvsCode: {0}", output.getCvsCode());
			print(out, "CvsConfNo: {0}", output.getCvsConfNo());
			print(out, "ReceiptNo: {0}", output.getReceiptNo());
			print(out, "PaymentTerm: {0}", output.getPaymentTerm());
			print(out, "ReceiptURL: {0}", output.getReceiptURL());
			print(out, "CustID: {0}", output.getCustID());
			print(out, "BkCode: {0}", output.getBkCode());
			print(out, "ConfNo: {0}", output.getConfNo());
			print(out, "PaymentURL: {0}", output.getPaymentURL());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
