package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.DisableBulkPaymentInput;
import com.gmo_pg.g_pay.client.output.DisableBulkPaymentOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * 一括決済サービス売上データ無効化呼出サーブレットサンプルクラス
 */
public class CallDisableBulkPaymentServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_TARGET_DATE = "TargetDate";
	private static final String P_RECORD_NUMBER = "RecordNumber";
	private static final String P_ORDER_ID = "OrderID";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        DisableBulkPaymentInput input = new DisableBulkPaymentInput();
        DisableBulkPaymentOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setTargetDate(req.getParameter(P_TARGET_DATE));
		input.setRecordNumber(
				req.getParameter(P_RECORD_NUMBER) == null || req.getParameter(P_RECORD_NUMBER).length() == 0
					? null : new Integer(req.getParameter(P_RECORD_NUMBER)));

		input.setOrderID(req.getParameter(P_ORDER_ID));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doDisableBulkPayment(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "RecordNumber: {0}", output.getRecordNumber());
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "RecordStatus: {0}", output.getRecordStatus());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
