package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.EntryExecTranBrandtokenInput;
import com.gmo_pg.g_pay.client.output.EntryExecTranBrandtokenOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * ブランドトークン決済登録・決済呼出サーブレットサンプルクラス
 */
public class CallEntryExecTranBrandtokenServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_JOB_CD = "JobCd";
	private static final String P_ITEM_CODE = "ItemCode";
	private static final String P_AMOUNT = "Amount";
	private static final String P_TAX = "Tax";
	private static final String P_ACCESS_ID = "AccessID";
	private static final String P_ACCESS_PASS = "AccessPass";
	private static final String P_TOKEN_TYPE = "TokenType";
	private static final String P_TOKEN = "Token";
	private static final String P_SITE_ID = "SiteID";
	private static final String P_SITE_PASS = "SitePass";
	private static final String P_MEMBER_ID = "MemberID";
	private static final String P_SEQ_MODE = "SeqMode";
	private static final String P_TOKEN_SEQ = "TokenSeq";
	private static final String P_CLIENT_FIELD1 = "ClientField1";
	private static final String P_CLIENT_FIELD2 = "ClientField2";
	private static final String P_CLIENT_FIELD3 = "ClientField3";

	
	public void doGet(HttpServletRequest req, HttpServletResponse res)
		throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
		throws ServletException, IOException {

		req.setCharacterEncoding("windows-31j");
		res.setContentType("text/html; charset=windows-31j");
		PrintWriter out = res.getWriter();

		PaymentClientImpl client = new PaymentClientImpl();
		EntryExecTranBrandtokenInput input = new EntryExecTranBrandtokenInput();
		EntryExecTranBrandtokenOutput output = null;

		// パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setOrderID(req.getParameter(P_ORDER_ID));
		input.setJobCd(req.getParameter(P_JOB_CD));
		input.setItemCode(req.getParameter(P_ITEM_CODE));
		input.setAmount(
				req.getParameter(P_AMOUNT) == null || req.getParameter(P_AMOUNT).length() == 0
					? null : new Integer(req.getParameter(P_AMOUNT)));

		input.setTax(
				req.getParameter(P_TAX) == null || req.getParameter(P_TAX).length() == 0
					? null : new Integer(req.getParameter(P_TAX)));

		input.setAccessID(req.getParameter(P_ACCESS_ID));
		input.setAccessPass(req.getParameter(P_ACCESS_PASS));
		input.setTokenType(req.getParameter(P_TOKEN_TYPE));
		input.setToken(req.getParameter(P_TOKEN));
		input.setSiteID(req.getParameter(P_SITE_ID));
		input.setSitePass(req.getParameter(P_SITE_PASS));
		input.setMemberID(req.getParameter(P_MEMBER_ID));
		input.setSeqMode(req.getParameter(P_SEQ_MODE));
		input.setTokenSeq(
				req.getParameter(P_TOKEN_SEQ) == null || req.getParameter(P_TOKEN_SEQ).length() == 0
					? null : new Integer(req.getParameter(P_TOKEN_SEQ)));

		input.setClientField1(req.getParameter(P_CLIENT_FIELD1));
		input.setClientField2(req.getParameter(P_CLIENT_FIELD2));
		input.setClientField3(req.getParameter(P_CLIENT_FIELD3));

		print(out, "INPUT(Entry): {0}",
				input.getEntryTranInput().toDataString(false));
		print(out, "INPUT(Exec): {0}",
				input.getExecTranInput().toDataString(false));

		try {
			// API呼び出し
			output = client.doEntryExecTranBrandtoken(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {

			if (output.isEntryErrorOccurred()) {
				List list = output.getEntryErrList();
				print(out, "ERROR(EntryTran):");
				for(Iterator it = list.iterator(); it.hasNext();) {
					ErrHolder eh = (ErrHolder)it.next();
					print(out, MessageFormat.format("ErrorCode: {0}  ErrorInfo: {1}",
									new Object[]{eh.getErrCode(), eh.getErrInfo()}));
				}
			}
			if (output.isExecErrorOccurred()) {
				List list = output.getExecErrList();
				print(out, "ERROR(ExecTran):");
				for(Iterator it = list.iterator(); it.hasNext();) {
					ErrHolder eh = (ErrHolder)it.next();
					print(out, MessageFormat.format("ErrorCode: {0}  ErrorInfo: {1}",
									new Object[]{eh.getErrCode(), eh.getErrInfo()}));
				}
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "AccessID: {0}", output.getAccessID());
			print(out, "AccessPass: {0}", output.getAccessPass());
			print(out, "Status: {0}", output.getStatus());
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "Forward: {0}", output.getForward());
			print(out, "Approve: {0}", output.getApprove());
			print(out, "TranID: {0}", output.getTranID());
			print(out, "TranDate: {0}", output.getTranDate());
			print(out, "ClientField1: {0}", output.getClientField1());
			print(out, "ClientField2: {0}", output.getClientField2());
			print(out, "ClientField3: {0}", output.getClientField3());


		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
