package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.EntryExecTranSuicaInput;
import com.gmo_pg.g_pay.client.output.EntryExecTranSuicaOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;

/**
 * モバイルSuica取引登録・決済実行呼出サーブレットサンプルクラス
 */
public class CallEntryExecTranSuicaServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_AMOUNT = "Amount";
	private static final String P_TAX = "Tax";
	private static final String P_ITEMNAME = "ItemName";
	private static final String P_MAILADDRESS = "MailAddress";
	private static final String P_SHOPMAILADDRESS = "ShopMailAdress";
	private static final String P_SUICAADDINFO1 = "SuicaAddInfo1";
	private static final String P_SUICAADDINFO2 = "SuicaAddInfo2";
	private static final String P_SUICAADDINFO3 = "SuicaAddInfo3";
	private static final String P_SUICAADDINFO4 = "SuicaAddInfo4";
	private static final String P_PAYMENTTERMDAY = "PaymentTermDay";
	private static final String P_PAYMENTTERMSEC = "PaymentTermSec";
	private static final String P_CLIENT_FIELD1 = "ClientField1";
	private static final String P_CLIENT_FIELD2 = "ClientField2";
	private static final String P_CLIENT_FIELD3 = "ClientField3";
	private static final String P_CLIENT_FIELD_FLAG = "ClientFieldFlag";

	public void doGet(HttpServletRequest req, HttpServletResponse res)
		throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
		throws ServletException, IOException {

		req.setCharacterEncoding("windows-31j");
		res.setContentType("text/html; charset=windows-31j");
		PrintWriter out = res.getWriter();

		PaymentClientImpl client = new PaymentClientImpl();
		EntryExecTranSuicaInput input = new EntryExecTranSuicaInput();
		EntryExecTranSuicaOutput output = null;

		// パラメータの設定
        input.setShopId(req.getParameter(P_SHOP_ID));
        input.setShopPass(req.getParameter(P_SHOP_PASS));
        input.setOrderId(req.getParameter(P_ORDER_ID));

        input.setAmount(
        		req.getParameter(P_AMOUNT) == null
        			? null : Integer.valueOf(req.getParameter(P_AMOUNT)));
        input.setTax(
        		req.getParameter(P_TAX) == null
        			? null : Integer.valueOf(req.getParameter(P_TAX)));

        input.setItemName(req.getParameter(P_ITEMNAME));
        input.setMailAddress(req.getParameter(P_MAILADDRESS));
        input.setShopMailAdress(req.getParameter(P_SHOPMAILADDRESS));
        input.setSuicaAddInfo1(req.getParameter(P_SUICAADDINFO1));
        input.setSuicaAddInfo2(req.getParameter(P_SUICAADDINFO2));
        input.setSuicaAddInfo3(req.getParameter(P_SUICAADDINFO3));
        input.setSuicaAddInfo4(req.getParameter(P_SUICAADDINFO4));
        input.setPaymentTermDay(
        		req.getParameter(P_PAYMENTTERMDAY) == null
        			? null : Integer.valueOf(req.getParameter(P_PAYMENTTERMDAY)));
        input.setPaymentTermSec(
        		req.getParameter(P_PAYMENTTERMSEC) == null
        			? null : Integer.valueOf(req.getParameter(P_PAYMENTTERMSEC)));

        input.setClientField1(req.getParameter(P_CLIENT_FIELD1));
        input.setClientField2(req.getParameter(P_CLIENT_FIELD2));
		input.setClientField3(req.getParameter(P_CLIENT_FIELD3));
		input.setClientFieldFlag(req.getParameter(P_CLIENT_FIELD_FLAG));
		print(out, "INPUT(Entry): {0}",
				input.getEntryTranInput().toDataString(false));
		print(out, "INPUT(Exec): {0}",
				input.getExecTranInput().toDataString(false));

		try {
			// API呼び出し
			output = client.doEntryExecTranSuica(input);
		} catch (PaymentException e) {
			//
			// [注意事項]
			// エラーが発生した場合は、お手数ですが加盟店様側でエラー処理を行っていただくようお願い致します。
			//
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {

			if (output.isEntryErrorOccurred()) {
				List list = output.getEntryErrList();
				print(out, "ERROR(EntryTran):");
				for(Iterator it = list.iterator(); it.hasNext();) {
					ErrHolder eh = (ErrHolder)it.next();
					print(out, MessageFormat.format("ErrorCode: {0}  ErrorInfo: {1}",
									new Object[]{eh.getErrCode(), eh.getErrInfo()}));
				}
			}
			if (output.isExecErrorOccurred()) {
				List list = output.getExecErrList();
				print(out, "ERROR(ExecTran):");
				for(Iterator it = list.iterator(); it.hasNext();) {
					ErrHolder eh = (ErrHolder)it.next();
					print(out, MessageFormat.format("ErrorCode: {0}  ErrorInfo: {1}",
									new Object[]{eh.getErrCode(), eh.getErrInfo()}));
				}
			}
		} else {
			print(out, "OUTPUT:");
	        print(out, "AccessID: {0}", output.getAccessId());
	        print(out, "AccessPass: {0}", output.getAccessPass());
	        print(out, "OrderID: {0}", output.getOrderId());
	        print(out, "SuicaOrderNo: {0}", output.getSuicaOrderNo());
        	print(out, "ReceiptNo: {0}",	output.getReceiptNo());
        	print(out, "PaymentTerm: {0}", output.getPaymentTerm());
	        print(out, "TranDate: {0}", output.getTranDate());
	        print(out, "CheckString: {0}", output.getCheckString());
	        print(out, "ClientField1: {0}", output.getClientField1());
	        print(out, "ClientField2: {0}", output.getClientField2());
	        print(out, "ClientField3: {0}", output.getClientField3());

		}
		out.flush();
}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
