package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.EntryTranDccInput;
import com.gmo_pg.g_pay.client.output.EntryTranDccOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * 多通貨クレジット決済（DCC)取引登録呼出サーブレットサンプルクラス
 */
public class CallEntryTranDccServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_DCC_CURRENCY = "DccCurrency";
	private static final String P_FTN = "Ftn";
	private static final String P_ITEM_CODE = "ItemCode";
	private static final String P_AMOUNT = "Amount";
	private static final String P_TAX = "Tax";
	private static final String P_TD_FLAG = "TdFlag";
	private static final String P_TD_TENANT_NAME = "TdTenantName";
	private static final String P_TDS_2_TYPE = "Tds2Type";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        EntryTranDccInput input = new EntryTranDccInput();
        EntryTranDccOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setOrderID(req.getParameter(P_ORDER_ID));
		input.setDccCurrency(req.getParameter(P_DCC_CURRENCY));
		input.setFtn(req.getParameter(P_FTN));
		input.setItemCode(req.getParameter(P_ITEM_CODE));
		input.setAmount(
				req.getParameter(P_AMOUNT) == null || req.getParameter(P_AMOUNT).length() == 0
					? null : new Integer(req.getParameter(P_AMOUNT)));

		input.setTax(
				req.getParameter(P_TAX) == null || req.getParameter(P_TAX).length() == 0
					? null : new Integer(req.getParameter(P_TAX)));

		input.setTdFlag(req.getParameter(P_TD_FLAG));
		input.setTdTenantName(req.getParameter(P_TD_TENANT_NAME));
        input.setTds2Type(req.getParameter(P_TDS_2_TYPE));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doEntryTranDcc(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "AccessID: {0}", output.getAccessID());
			print(out, "AccessPass: {0}", output.getAccessPass());
			print(out, "DccCurrency: {0}", output.getDccCurrency());
			print(out, "DccAmount: {0}", output.getDccAmount());
			print(out, "DccRate: {0}", output.getDccRate());
			print(out, "Ftn: {0}", output.getFtn());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
