package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.ExecTranJcbPrecaInput;
import com.gmo_pg.g_pay.client.output.ExecTranJcbPrecaOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * JCBプリカ決済実行呼出サーブレットサンプルクラス
 */
public class CallExecTranJcbPrecaServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ACCESS_ID = "AccessID";
	private static final String P_ACCESS_PASS = "AccessPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_CARD_NO = "CardNo";
	private static final String P_APPROVAL_NO = "ApprovalNo";
	private static final String P_CLIENT_FIELD1 = "ClientField1";
	private static final String P_CLIENT_FIELD2 = "ClientField2";
	private static final String P_CLIENT_FIELD3 = "ClientField3";
	private static final String P_CARRY_INFO = "CarryInfo";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        ExecTranJcbPrecaInput input = new ExecTranJcbPrecaInput();
        ExecTranJcbPrecaOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setAccessID(req.getParameter(P_ACCESS_ID));
		input.setAccessPass(req.getParameter(P_ACCESS_PASS));
		input.setOrderID(req.getParameter(P_ORDER_ID));
		input.setCardNo(req.getParameter(P_CARD_NO));
		input.setApprovalNo(req.getParameter(P_APPROVAL_NO));
		input.setClientField1(req.getParameter(P_CLIENT_FIELD1));
		input.setClientField2(req.getParameter(P_CLIENT_FIELD2));
		input.setClientField3(req.getParameter(P_CLIENT_FIELD3));
		input.setCarryInfo(req.getParameter(P_CARRY_INFO));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doExecTranJcbPreca(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "Status: {0}", output.getStatus());
			print(out, "Amount: {0}", output.getAmount());
			print(out, "Tax: {0}", output.getTax());
			print(out, "BeforeBalance: {0}", output.getBeforeBalance());
			print(out, "AfterBalance: {0}", output.getAfterBalance());
			print(out, "CardActivateStatus: {0}", output.getCardActivateStatus());
			print(out, "CardTermStatus: {0}", output.getCardTermStatus());
			print(out, "CardInvalidStatus: {0}", output.getCardInvalidStatus());
			print(out, "CardWebInquiryStatus: {0}", output.getCardWebInquiryStatus());
			print(out, "CardValidLimit: {0}", output.getCardValidLimit());
			print(out, "CardTypeCode: {0}", output.getCardTypeCode());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
