package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.ExecTranPaypalInput;
import com.gmo_pg.g_pay.client.output.ErrHolder;
import com.gmo_pg.g_pay.client.output.ExecTranPaypalOutput;

/**
 * Paypal決済実行サーブレットサンプルクラス
 */
public class CallExecTranPaypalServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ACCESS_ID = "AccessID";
	private static final String P_ACCESS_PASS = "AccessPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_ITEM_NAME = "ItemName";
	private static final String P_REDIRECT_URL = "RedirectURL";
	private static final String P_LOCALE = "Locale";
	private static final String P_CLIENT_FIELD1 = "ClientField1";
	private static final String P_CLIENT_FIELD2 = "ClientField2";
	private static final String P_CLIENT_FIELD3 = "ClientField3";
	private static final String P_CLIENT_FIELD_FLAG = "ClientFieldFlag";
	private static final String P_PAYMENT_TYPE = "PaymentType";
	private static final String P_PAYPAL_BILLING_AGREEMENT_ID = "PaypalBillingAgreementID";
	private static final String P_SHIP_FLG = "ShipFlg";
	private static final String P_SHIP_TO_NAME = "ShipToName";
	private static final String P_SHIP_TO_ZIP = "ShipToZip";
	private static final String P_SHIP_TO_COUNTRY_CODE = "ShipToCountryCode";
	private static final String P_SHIP_TO_STATE = "ShipToState";
	private static final String P_SHIP_TO_CITY = "ShipToCity";
	private static final String P_SHIP_TO_STREET = "ShipToStreet";
	private static final String P_SHIP_TO_STREET2 = "ShipToStreet2";

	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {

		req.setCharacterEncoding("windows-31j");
		res.setContentType("text/html; charset=windows-31j");
		PrintWriter out = res.getWriter();

		PaymentClientImpl client = new PaymentClientImpl();
		ExecTranPaypalInput input = new ExecTranPaypalInput();
		ExecTranPaypalOutput output = null;

		// パラメータの設定
		input.setShopId(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setOrderId(req.getParameter(P_ORDER_ID));
		input.setAccessId(req.getParameter(P_ACCESS_ID));
		input.setAccessPass(req.getParameter(P_ACCESS_PASS));
		input.setOrderId(req.getParameter(P_ORDER_ID));
		input.setItemName(req.getParameter(P_ITEM_NAME));
		input.setRedirectURL(req.getParameter(P_REDIRECT_URL));
		input.setLocale(req.getParameter(P_LOCALE));
		input.setClientField1(req.getParameter(P_CLIENT_FIELD1));
		input.setClientField2(req.getParameter(P_CLIENT_FIELD2));
		input.setClientField3(req.getParameter(P_CLIENT_FIELD3));
		input.setClientFieldFlag(req.getParameter(P_CLIENT_FIELD_FLAG));
		input.setPaymentType(req.getParameter(P_PAYMENT_TYPE));
		input.setPaypalBillingAgreementId(req.getParameter(P_PAYPAL_BILLING_AGREEMENT_ID));
		input.setShipFlg(req.getParameter(P_SHIP_FLG));
		input.setShipToName(req.getParameter(P_SHIP_TO_NAME));
		input.setShipToZip(req.getParameter(P_SHIP_TO_ZIP));
		input.setShipToCountryCode(req.getParameter(P_SHIP_TO_COUNTRY_CODE));
		input.setShipToState(req.getParameter(P_SHIP_TO_STATE));
		input.setShipToCity(req.getParameter(P_SHIP_TO_CITY));
		input.setShipToStreet(req.getParameter(P_SHIP_TO_STREET));
		input.setShipToStreet2(req.getParameter(P_SHIP_TO_STREET2));

		print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doExecTranPaypal(input);
		} catch (PaymentException e) {
			//
			// [注意事項]
			// エラーが発生した場合は、お手数ですが加盟店様側でエラー処理を行っていただくようお願い致します。
			//
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for (Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder) it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}", new Object[] {
						eh.getErrCode(), eh.getErrInfo() });

			}
		} else {
			print(out, "OUTPUT:");
			print(out, "OrderID: {0}", output.getOrderId());
			print(out, "ClientField1: {0}", output.getClientField1());
			print(out, "ClientField2: {0}", output.getClientField2());
			print(out, "ClientField3: {0}", output.getClientField3());
			print(out, "ShopID: {0}", output.getShopId());
			print(out, "Status: {0}", output.getStatus());
			print(out, "TranDate: {0}", output.getTranDate());
			print(out, "TranID: {0}", output.getTranId());
			print(out, "CheckString: {0}", output.getCheckString());
		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[] { obj });
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt, obj));
		out.print(MessageFormat.format(fmt, obj));
		out.print("<br>");
		out.println();
	}
}
