package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.ExecTranSbInput;
import java.util.Iterator;
import java.util.List;
import com.gmo_pg.g_pay.client.output.ExecTranSbOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;


/**
 * ソフトバンクケータイ支払い決済実行呼出サーブレットサンプルクラス
 */
public class CallExecTranSbServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ACCESS_ID = "AccessID";
	private static final String P_ACCESS_PASS = "AccessPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_CLIENT_FIELD1 = "ClientField1";
	private static final String P_CLIENT_FIELD2 = "ClientField2";
	private static final String P_CLIENT_FIELD3 = "ClientField3";
	private static final String P_RET_URL = "RetURL";
	private static final String P_PAYMENT_TERM_SEC = "PaymentTermSec";
	private static final String P_ITEM_NAME = "ItemName";
	private static final String P_SB_ACCEPT_CODE = "SbAcceptCode";

	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        ExecTranSbInput input = new ExecTranSbInput();
        ExecTranSbOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setAccessID(req.getParameter(P_ACCESS_ID));
		input.setAccessPass(req.getParameter(P_ACCESS_PASS));
		input.setOrderID(req.getParameter(P_ORDER_ID));
		input.setClientField1(req.getParameter(P_CLIENT_FIELD1));
		input.setClientField2(req.getParameter(P_CLIENT_FIELD2));
		input.setClientField3(req.getParameter(P_CLIENT_FIELD3));
		input.setRetURL(req.getParameter(P_RET_URL));
		input.setPaymentTermSec(
				req.getParameter(P_PAYMENT_TERM_SEC) == null || req.getParameter(P_PAYMENT_TERM_SEC).length() == 0
					? null : Integer.valueOf(req.getParameter(P_PAYMENT_TERM_SEC)));

		input.setItemName(req.getParameter(P_ITEM_NAME));
		input.setSbAcceptCode(req.getParameter(P_SB_ACCEPT_CODE));
		print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doExecTranSb(input);
		} catch (PaymentException e) {
			//
			// [注意事項]
			// エラーが発生した場合は、お手数ですが加盟店様側でエラー処理を行っていただくようお願い致します。
			//
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});

			}
		} else {
			print(out, "OUTPUT:");
			print(out, "AccessID: {0}", output.getAccessID());
			print(out, "Token: {0}", output.getToken());
			print(out, "StartURL: {0}", output.getStartURL());
			print(out, "StartLimitDate: {0}", output.getStartLimitDate());
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "Status: {0}", output.getStatus());
			print(out, "TranDate: {0}", output.getTranDate());
			print(out, "SbTrackingId: {0}", output.getSbTrackingId());
			print(out, "CheckString: {0}", output.getCheckString());
		}
        out.flush();
    }

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
