package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.ExecTranSuicaInput;
import com.gmo_pg.g_pay.client.output.ErrHolder;
import com.gmo_pg.g_pay.client.output.ExecTranSuicaOutput;

/**
 * モバイルSuica決済実行呼出サーブレットサンプルクラス
 */
public class CallExecTranSuicaServlet extends HttpServlet {

	private static final String P_ACCESS_ID = "AccessID";
	private static final String P_ACCESS_PASS = "AccessPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_ITEMNAME = "ItemName";
	private static final String P_MAILADDRESS = "MailAddress";
	private static final String P_SHOPMAILADDRESS = "ShopMailAdress";
	private static final String P_SUICAADDINFO1 = "SuicaAddInfo1";
	private static final String P_SUICAADDINFO2 = "SuicaAddInfo2";
	private static final String P_SUICAADDINFO3 = "SuicaAddInfo3";
	private static final String P_SUICAADDINFO4 = "SuicaAddInfo4";
	private static final String P_PAYMENTTERMDAY = "PaymentTermDay";
	private static final String P_PAYMENTTERMSEC = "PaymentTermSec";
	private static final String P_CLIENT_FIELD1 = "ClientField1";
	private static final String P_CLIENT_FIELD2 = "ClientField2";
	private static final String P_CLIENT_FIELD3 = "ClientField3";
	private static final String P_CLIENT_FIELD_FLAG = "ClientFieldFlag";

	public void doGet(HttpServletRequest req, HttpServletResponse res)
	    	throws ServletException, IOException {
		doPost(req, res);
	}

    public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        ExecTranSuicaInput input = new ExecTranSuicaInput();
        ExecTranSuicaOutput output = null;

        // パラメータの設定
        input.setAccessId(req.getParameter(P_ACCESS_ID));
        input.setAccessPass(req.getParameter(P_ACCESS_PASS));
        input.setOrderId(req.getParameter(P_ORDER_ID));
        input.setItemName(req.getParameter(P_ITEMNAME));
        input.setMailAddress(req.getParameter(P_MAILADDRESS));
        input.setShopMailAdress(req.getParameter(P_SHOPMAILADDRESS));
        input.setSuicaAddInfo1(req.getParameter(P_SUICAADDINFO1));
        input.setSuicaAddInfo2(req.getParameter(P_SUICAADDINFO2));
        input.setSuicaAddInfo3(req.getParameter(P_SUICAADDINFO3));
        input.setSuicaAddInfo4(req.getParameter(P_SUICAADDINFO4));
        input.setPaymentTermDay(
        		req.getParameter(P_PAYMENTTERMDAY) == null
        			? null : Integer.valueOf(req.getParameter(P_PAYMENTTERMDAY)));
        input.setPaymentTermSec(
        		req.getParameter(P_PAYMENTTERMSEC) == null
        			? null : Integer.valueOf(req.getParameter(P_PAYMENTTERMSEC)));

        input.setClientField1(req.getParameter(P_CLIENT_FIELD1));
        input.setClientField2(req.getParameter(P_CLIENT_FIELD2));
		input.setClientField3(req.getParameter(P_CLIENT_FIELD3));
		input.setClientFieldFlag(req.getParameter(P_CLIENT_FIELD_FLAG));
       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doExecTranSuica(input);
		} catch (PaymentException e) {
			//
			// [注意事項]
			// エラーが発生した場合は、お手数ですが加盟店様側でエラー処理を行っていただくようお願い致します。
			//
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
        if (output.isErrorOccurred()) {
        	List list = output.getErrList();
    		print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
        		print(out, MessageFormat.format("ErrorCode: {0}  ErrorInfo: {1}",
        						new Object[]{eh.getErrCode(), eh.getErrInfo()}));

        	}
        } else {
    		print(out, "OUTPUT:");
        	print(out, "SuicaOrderNo: {0}", output.getSuicaOrderNo());
        	print(out, "ReceiptNo: {0}",	output.getReceiptNo());
        	print(out, "PaymentTerm: {0}", output.getPaymentTerm());
        	print(out, "TranDate: {0}", output.getTranDate());
        	print(out, "CheckString: {0}", output.getCheckString());
        	print(out, "ClientField1: {0}", output.getClientField1());
        	print(out, "ClientField2: {0}", output.getClientField2());
        	print(out, "ClientField3: {0}", output.getClientField3());

        }
        out.flush();
    }

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
