package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.ExecTranVirtualaccountInput;
import com.gmo_pg.g_pay.client.output.ExecTranVirtualaccountOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * 銀行振込(バーチャル口座)決済実行呼出サーブレットサンプルクラス
 */
public class CallExecTranVirtualaccountServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ACCESS_ID = "AccessID";
	private static final String P_ACCESS_PASS = "AccessPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_TRADE_DAYS = "TradeDays";
	private static final String P_TRADE_REASON = "TradeReason";
	private static final String P_TRADE_CLIENT_NAME = "TradeClientName";
	private static final String P_TRADE_CLIENT_MAILADDRESS = "TradeClientMailaddress";
	private static final String P_CLIENT_FIELD1 = "ClientField1";
	private static final String P_CLIENT_FIELD2 = "ClientField2";
	private static final String P_CLIENT_FIELD3 = "ClientField3";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        ExecTranVirtualaccountInput input = new ExecTranVirtualaccountInput();
        ExecTranVirtualaccountOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setAccessID(req.getParameter(P_ACCESS_ID));
		input.setAccessPass(req.getParameter(P_ACCESS_PASS));
		input.setOrderID(req.getParameter(P_ORDER_ID));
		input.setTradeDays(
				req.getParameter(P_TRADE_DAYS) == null || req.getParameter(P_TRADE_DAYS).length() == 0
					? null : new Integer(req.getParameter(P_TRADE_DAYS)));

		input.setTradeReason(req.getParameter(P_TRADE_REASON));
		input.setTradeClientName(req.getParameter(P_TRADE_CLIENT_NAME));
		input.setTradeClientMailaddress(req.getParameter(P_TRADE_CLIENT_MAILADDRESS));
		input.setClientField1(req.getParameter(P_CLIENT_FIELD1));
		input.setClientField2(req.getParameter(P_CLIENT_FIELD2));
		input.setClientField3(req.getParameter(P_CLIENT_FIELD3));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doExecTranVirtualaccount(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "AccessID: {0}", output.getAccessID());
			print(out, "BankCode: {0}", output.getBankCode());
			print(out, "BankName: {0}", output.getBankName());
			print(out, "BranchCode: {0}", output.getBranchCode());
			print(out, "BranchName: {0}", output.getBranchName());
			print(out, "AccountType: {0}", output.getAccountType());
			print(out, "AccountNumber: {0}", output.getAccountNumber());
			print(out, "AvailableDate: {0}", output.getAvailableDate());
			print(out, "TradeCode: {0}", output.getTradeCode());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
