package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.ExecTranWebmoneyQuickInput;
import com.gmo_pg.g_pay.client.output.ExecTranWebmoneyQuickOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * Webmoneyクイック決済実行呼出サーブレットサンプルクラス
 */
public class CallExecTranWebmoneyQuickServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ACCESS_ID = "AccessID";
	private static final String P_ACCESS_PASS = "AccessPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_QUICK_ID = "QuickID";
	private static final String P_ITEM_NAME = "ItemName";
	private static final String P_PAYMENT_TERM_DAY = "PaymentTermDay";
	private static final String P_REDIRECT_URL = "RedirectURL";
	private static final String P_CLIENT_FIELD1 = "ClientField1";
	private static final String P_CLIENT_FIELD2 = "ClientField2";
	private static final String P_CLIENT_FIELD3 = "ClientField3";
	private static final String P_CLIENT_FIELD_FLAG = "ClientFieldFlag";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        ExecTranWebmoneyQuickInput input = new ExecTranWebmoneyQuickInput();
        ExecTranWebmoneyQuickOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setAccessID(req.getParameter(P_ACCESS_ID));
		input.setAccessPass(req.getParameter(P_ACCESS_PASS));
		input.setOrderID(req.getParameter(P_ORDER_ID));
		input.setQuickID(req.getParameter(P_QUICK_ID));
		input.setItemName(req.getParameter(P_ITEM_NAME));
		input.setPaymentTermDay(
				req.getParameter(P_PAYMENT_TERM_DAY) == null || req.getParameter(P_PAYMENT_TERM_DAY).length() == 0
					? null : new Integer(req.getParameter(P_PAYMENT_TERM_DAY)));

		input.setRedirectURL(req.getParameter(P_REDIRECT_URL));
		input.setClientField1(req.getParameter(P_CLIENT_FIELD1));
		input.setClientField2(req.getParameter(P_CLIENT_FIELD2));
		input.setClientField3(req.getParameter(P_CLIENT_FIELD3));
		input.setClientFieldFlag(req.getParameter(P_CLIENT_FIELD_FLAG));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doExecTranWebmoneyQuick(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "ShopID: {0}", output.getShopID());
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "QuickID: {0}", output.getQuickID());
			print(out, "Status: {0}", output.getStatus());
			print(out, "TranDate: {0}", output.getTranDate());
			print(out, "PayCancel: {0}", output.getPayCancel());
			print(out, "ManagementNo: {0}", output.getManagementNo());
			print(out, "SettleCode: {0}", output.getSettleCode());
			print(out, "CampaignUrl: {0}", output.getCampaignUrl());
			print(out, "CheckString: {0}", output.getCheckString());
			print(out, "ClientField1: {0}", output.getClientField1());
			print(out, "ClientField2: {0}", output.getClientField2());
			print(out, "ClientField3: {0}", output.getClientField3());
			print(out, "NextStep: {0}", output.getNextStep());
			print(out, "PaymentTerm: {0}", output.getPaymentTerm());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
