package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.ExecTranWebmoneyInput;
import com.gmo_pg.g_pay.client.output.ErrHolder;
import com.gmo_pg.g_pay.client.output.ExecTranWebmoneyOutput;

/**
 * Webmoney決済実行サーブレットサンプルクラス
 *
 * @author GMO PaymentGateway
 * @modified 2010/04/08
 */
public class CallExecTranWebmoneyServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ACCESS_ID = "AccessID";
	private static final String P_ACCESS_PASS = "AccessPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_ITEM_NAME = "ItemName";
	private static final String P_CUSTOMERNAME = "CustomerName";
	private static final String P_MAILADDRESS = "MailAddress";
	private static final String P_SHOPMAILADDRESS = "ShopMailAddress";
	private static final String P_PAYMENTTERMDAY = "PaymentTermDay";
	private static final String P_REDIRECT_URL = "RedirectURL";
	private static final String P_CLIENT_FIELD1 = "ClientField1";
	private static final String P_CLIENT_FIELD2 = "ClientField2";
	private static final String P_CLIENT_FIELD3 = "ClientField3";
	private static final String P_CLIENT_FIELD_FLAG = "ClientFieldFlag";

	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {

		req.setCharacterEncoding("windows-31j");
		res.setContentType("text/html; charset=windows-31j");
		PrintWriter out = res.getWriter();

		PaymentClientImpl client = new PaymentClientImpl();
		ExecTranWebmoneyInput input = new ExecTranWebmoneyInput();
		ExecTranWebmoneyOutput output = null;

		// パラメータの設定
		input.setShopId(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setOrderId(req.getParameter(P_ORDER_ID));
		input.setAccessId(req.getParameter(P_ACCESS_ID));
		input.setAccessPass(req.getParameter(P_ACCESS_PASS));
		input.setOrderId(req.getParameter(P_ORDER_ID));
		input.setItemName(req.getParameter(P_ITEM_NAME));
		input.setCustomerName(req.getParameter(P_CUSTOMERNAME));
		input.setMailAddress(req.getParameter(P_MAILADDRESS));
		input.setShopMailAddress(req.getParameter(P_SHOPMAILADDRESS));
		input
				.setPaymentTermDay(req.getParameter(P_PAYMENTTERMDAY) == null ? null
						: Integer.valueOf(req.getParameter(P_PAYMENTTERMDAY)));
		input.setRedirectURL(req.getParameter(P_REDIRECT_URL));
		input.setClientField1(req.getParameter(P_CLIENT_FIELD1));
		input.setClientField2(req.getParameter(P_CLIENT_FIELD2));
		input.setClientField3(req.getParameter(P_CLIENT_FIELD3));
		input.setClientFieldFlag(req.getParameter(P_CLIENT_FIELD_FLAG));

		print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doExecTranWebmoney(input);
		} catch (PaymentException e) {
			//
			// [注意事項]
			// エラーが発生した場合は、お手数ですが加盟店様側でエラー処理を行っていただくようお願い致します。
			//
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for (Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder) it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}", new Object[] {
						eh.getErrCode(), eh.getErrInfo() });

			}
		} else {
			print(out, "OUTPUT:");
			print(out, "OrderID: {0}", output.getOrderId());
			print(out, "PaymentTerm: {0}", output.getPaymentTerm());
			print(out, "TranDate: {0}", output.getTranDate());
			print(out, "CheckString: {0}", output.getCheckString());
			print(out, "ClientField1: {0}", output.getClientField1());
			print(out, "ClientField2: {0}", output.getClientField2());
			print(out, "ClientField3: {0}", output.getClientField3());
		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[] { obj });
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt, obj));
		out.print(MessageFormat.format(fmt, obj));
		out.print("<br>");
		out.println();
	}
}
