package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.MaillinkRegiststartInput;
import com.gmo_pg.g_pay.client.output.MaillinkRegiststartOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * メールリンクカード登録呼出サーブレットサンプルクラス
 */
public class CallMaillinkRegiststartServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_EXEC_MODE = "ExecMode";
	private static final String P_SITE_ID = "SiteID";
	private static final String P_MEMBER_ID = "MemberID";
	private static final String P_MEMBER_NAME = "MemberName";
	private static final String P_MAIL_LINK_ORDER_NO = "MailLinkOrderNo";
	private static final String P_MAIL_ADDRESS = "MailAddress";
	private static final String P_LANG = "Lang";
	private static final String P_TEMPLATE_NO = "TemplateNo";
	private static final String P_EXPIRE_DAYS = "ExpireDays";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        MaillinkRegiststartInput input = new MaillinkRegiststartInput();
        MaillinkRegiststartOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setExecMode(req.getParameter(P_EXEC_MODE));
		input.setSiteID(req.getParameter(P_SITE_ID));
		input.setMemberID(req.getParameter(P_MEMBER_ID));
		input.setMemberName(req.getParameter(P_MEMBER_NAME));
		input.setMailLinkOrderNo(req.getParameter(P_MAIL_LINK_ORDER_NO));
		input.setMailAddress(req.getParameter(P_MAIL_ADDRESS));
		input.setLang(req.getParameter(P_LANG));
		input.setTemplateNo(
				req.getParameter(P_TEMPLATE_NO) == null || req.getParameter(P_TEMPLATE_NO).length() == 0
					? null : new Integer(req.getParameter(P_TEMPLATE_NO)));

		input.setExpireDays(
				req.getParameter(P_EXPIRE_DAYS) == null || req.getParameter(P_EXPIRE_DAYS).length() == 0
					? null : new Integer(req.getParameter(P_EXPIRE_DAYS)));


       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doMaillinkRegiststart(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "ShopID: {0}", output.getShopID());
			print(out, "MailLinkOrderNo: {0}", output.getMailLinkOrderNo());
			print(out, "MaillinkUrl: {0}", output.getMaillinkUrl());
			print(out, "ProcessDate: {0}", output.getProcessDate());
			print(out, "ExpireDate: {0}", output.getExpireDate());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
