package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.MaillinkstartInput;
import com.gmo_pg.g_pay.client.output.MaillinkstartOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;

import java.math.BigDecimal;

/**
 * メールリンク決済開始呼出サーブレットサンプルクラス
 */
public class CallMaillinkstartServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_EXEC_MODE = "ExecMode";
	private static final String P_MAIL_LINK_ORDER_NO = "MailLinkOrderNo";
	private static final String P_ITEM_NAME = "ItemName";
	private static final String P_CURRENCY = "Currency";
	private static final String P_AMOUNT = "Amount";
	private static final String P_TAX = "Tax";
	private static final String P_CUSTOMER_NAME = "CustomerName";
	private static final String P_MAIL_ADDRESS = "MailAddress";
	private static final String P_TEMPLATE_NO = "TemplateNo";
	private static final String P_LANG = "Lang";
	private static final String P_EXPIRE_DAYS = "ExpireDays";
	private static final String P_CLIENT_FIELD1 = "ClientField1";
	private static final String P_CLIENT_FIELD2 = "ClientField2";
	private static final String P_CLIENT_FIELD3 = "ClientField3";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        MaillinkstartInput input = new MaillinkstartInput();
        MaillinkstartOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setExecMode(req.getParameter(P_EXEC_MODE));
		input.setMailLinkOrderNo(req.getParameter(P_MAIL_LINK_ORDER_NO));
		input.setItemName(req.getParameter(P_ITEM_NAME));
		input.setCurrency(req.getParameter(P_CURRENCY));
		input.setAmount(
				req.getParameter(P_AMOUNT) == null || req.getParameter(P_AMOUNT).length() == 0
					? null : new BigDecimal(req.getParameter(P_AMOUNT)));

		input.setTax(
				req.getParameter(P_TAX) == null || req.getParameter(P_TAX).length() == 0
					? null : new BigDecimal(req.getParameter(P_TAX)));

		input.setCustomerName(req.getParameter(P_CUSTOMER_NAME));
		input.setMailAddress(req.getParameter(P_MAIL_ADDRESS));
		input.setTemplateNo(
				req.getParameter(P_TEMPLATE_NO) == null || req.getParameter(P_TEMPLATE_NO).length() == 0
					? null : new Integer(req.getParameter(P_TEMPLATE_NO)));

		input.setLang(req.getParameter(P_LANG));
		input.setExpireDays(
				req.getParameter(P_EXPIRE_DAYS) == null || req.getParameter(P_EXPIRE_DAYS).length() == 0
					? null : new Integer(req.getParameter(P_EXPIRE_DAYS)));

		input.setClientField1(req.getParameter(P_CLIENT_FIELD1));
		input.setClientField2(req.getParameter(P_CLIENT_FIELD2));
		input.setClientField3(req.getParameter(P_CLIENT_FIELD3));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doMaillinkstart(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "ShopID: {0}", output.getShopID());
			print(out, "MailLinkOrderNo: {0}", output.getMailLinkOrderNo());
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "MaillinkUrl: {0}", output.getMaillinkUrl());
			print(out, "ProcessDate: {0}", output.getProcessDate());
			print(out, "ExpireDate: {0}", output.getExpireDate());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
