package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.PaysleBarcodeInput;
import com.gmo_pg.g_pay.client.output.PaysleBarcodeOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * Paysleバーコード発行呼出サーブレットサンプルクラス
 */
public class CallPaysleBarcodeServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ACCESS_ID = "AccessID";
	private static final String P_ACCESS_PASS = "AccessPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_DEVICE_NAME = "DeviceName";
	private static final String P_OS_VERSION = "OsVersion";
	private static final String P_WIN_WIDTH = "WinWidth";
	private static final String P_WIN_HEIGHT = "WinHeight";
	private static final String P_XDPI = "Xdpi";
	private static final String P_YDPI = "Ydpi";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        PaysleBarcodeInput input = new PaysleBarcodeInput();
        PaysleBarcodeOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setAccessID(req.getParameter(P_ACCESS_ID));
		input.setAccessPass(req.getParameter(P_ACCESS_PASS));
		input.setOrderID(req.getParameter(P_ORDER_ID));
		input.setDeviceName(req.getParameter(P_DEVICE_NAME));
		input.setOsVersion(req.getParameter(P_OS_VERSION));
		input.setWinWidth(
				req.getParameter(P_WIN_WIDTH) == null || req.getParameter(P_WIN_WIDTH).length() == 0
					? null : new Integer(req.getParameter(P_WIN_WIDTH)));

		input.setWinHeight(
				req.getParameter(P_WIN_HEIGHT) == null || req.getParameter(P_WIN_HEIGHT).length() == 0
					? null : new Integer(req.getParameter(P_WIN_HEIGHT)));

		input.setXdpi(
				req.getParameter(P_XDPI) == null || req.getParameter(P_XDPI).length() == 0
					? null : new Integer(req.getParameter(P_XDPI)));

		input.setYdpi(
				req.getParameter(P_YDPI) == null || req.getParameter(P_YDPI).length() == 0
					? null : new Integer(req.getParameter(P_YDPI)));


       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doPaysleBarcode(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "PaysleBarcodeWidth: {0}", output.getPaysleBarcodeWidth());
			print(out, "PaysleBarcodeHeight: {0}", output.getPaysleBarcodeHeight());
			print(out, "PaysleBarcodeFormat: {0}", output.getPaysleBarcodeFormat());
			print(out, "PaysleBarcode: {0}", output.getPaysleBarcode());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
