package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.RegisterBulkPaymentInput;
import com.gmo_pg.g_pay.client.output.RegisterBulkPaymentOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * 一括決済サービス売上データ登録呼出サーブレットサンプルクラス
 */
public class CallRegisterBulkPaymentServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_TARGET_DATE = "TargetDate";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_MEMBER_ID = "MemberID";
	private static final String P_CARD_SEQ = "CardSeq";
	private static final String P_CARD_NO = "CardNo";
	private static final String P_EXPIRE = "Expire";
	private static final String P_AMOUNT = "Amount";
	private static final String P_TAX = "Tax";
	private static final String P_ITEM_CODE = "ItemCode";
	private static final String P_CLIENT_FIELD1 = "ClientField1";
	private static final String P_CLIENT_FIELD2 = "ClientField2";
	private static final String P_CLIENT_FIELD3 = "ClientField3";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        RegisterBulkPaymentInput input = new RegisterBulkPaymentInput();
        RegisterBulkPaymentOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setTargetDate(req.getParameter(P_TARGET_DATE));
		input.setOrderID(req.getParameter(P_ORDER_ID));
		input.setMemberID(req.getParameter(P_MEMBER_ID));
		input.setCardSeq(
				req.getParameter(P_CARD_SEQ) == null || req.getParameter(P_CARD_SEQ).length() == 0
					? null : new Integer(req.getParameter(P_CARD_SEQ)));

		input.setCardNo(req.getParameter(P_CARD_NO));
		input.setExpire(req.getParameter(P_EXPIRE));
		input.setAmount(
				req.getParameter(P_AMOUNT) == null || req.getParameter(P_AMOUNT).length() == 0
					? null : new Integer(req.getParameter(P_AMOUNT)));

		input.setTax(
				req.getParameter(P_TAX) == null || req.getParameter(P_TAX).length() == 0
					? null : new Integer(req.getParameter(P_TAX)));

		input.setItemCode(req.getParameter(P_ITEM_CODE));
		input.setClientField1(req.getParameter(P_CLIENT_FIELD1));
		input.setClientField2(req.getParameter(P_CLIENT_FIELD2));
		input.setClientField3(req.getParameter(P_CLIENT_FIELD3));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doRegisterBulkPayment(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "RecordNumber: {0}", output.getRecordNumber());
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "RecordStatus: {0}", output.getRecordStatus());
			print(out, "AuthCode: {0}", output.getAuthCode());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
