package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.SearchAddressAmazonpayInput;
import com.gmo_pg.g_pay.client.output.SearchAddressAmazonpayOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * Amazon Pay住所情報参照呼出サーブレットサンプルクラス
 */
public class CallSearchAddressAmazonpayServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_AMAZON_CHECKOUT_SESSION_ID = "AmazonCheckoutSessionID";
	private static final String P_AMAZON_BUYER_TOKEN = "AmazonBuyerToken";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        SearchAddressAmazonpayInput input = new SearchAddressAmazonpayInput();
        SearchAddressAmazonpayOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setOrderID(req.getParameter(P_ORDER_ID));
		input.setAmazonCheckoutSessionID(req.getParameter(P_AMAZON_CHECKOUT_SESSION_ID));
		input.setAmazonBuyerToken(req.getParameter(P_AMAZON_BUYER_TOKEN));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doSearchAddressAmazonpay(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "ShippingCountryCode: {0}", output.getShippingCountryCode());
			print(out, "ShippingCity: {0}", output.getShippingCity());
			print(out, "ShippingCounty: {0}", output.getShippingCounty());
			print(out, "ShippingDistrict: {0}", output.getShippingDistrict());
			print(out, "ShippingPostalCode: {0}", output.getShippingPostalCode());
			print(out, "ShippingStateOrRegion: {0}", output.getShippingStateOrRegion());
			print(out, "ShippingAddressLine1: {0}", output.getShippingAddressLine1());
			print(out, "ShippingAddressLine2: {0}", output.getShippingAddressLine2());
			print(out, "ShippingAddressLine3: {0}", output.getShippingAddressLine3());
			print(out, "ShippingName: {0}", output.getShippingName());
			print(out, "ShippingPhoneNumber: {0}", output.getShippingPhoneNumber());
			print(out, "AmazonBuyerID: {0}", output.getAmazonBuyerID());
			print(out, "AmazonAccountName: {0}", output.getAmazonAccountName());
			print(out, "AmazonMailAddress: {0}", output.getAmazonMailAddress());
			print(out, "AmazonPhoneNumber: {0}", output.getAmazonPhoneNumber());
			print(out, "BillingCountryCode: {0}", output.getBillingCountryCode());
			print(out, "BillingCity: {0}", output.getBillingCity());
			print(out, "BillingCounty: {0}", output.getBillingCounty());
			print(out, "BillingDistrict: {0}", output.getBillingDistrict());
			print(out, "BillingPostalCode: {0}", output.getBillingPostalCode());
			print(out, "BillingStateOrRegion: {0}", output.getBillingStateOrRegion());
			print(out, "BillingAddressLine1: {0}", output.getBillingAddressLine1());
			print(out, "BillingAddressLine2: {0}", output.getBillingAddressLine2());
			print(out, "BillingAddressLine3: {0}", output.getBillingAddressLine3());
			print(out, "BillingName: {0}", output.getBillingName());
			print(out, "BillingPhoneNumber: {0}", output.getBillingPhoneNumber());
			print(out, "PaymentDescriptor: {0}", output.getPaymentDescriptor());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
