package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.SearchCardReverseInput;
import com.gmo_pg.g_pay.client.output.ErrHolder;
import com.gmo_pg.g_pay.client.output.SearchCardReverseOutput;
import com.gmo_pg.g_pay.client.output.SearchCardReverseOutput.MemberCardInfo;

/**
 * カードID逆引きサーブレットサンプルクラス
 */
public class CallSearchCardReverseServlet extends HttpServlet {

	private static final String P_SITE_ID = "SiteID";
	private static final String P_SITE_PASS = "SitePass";
	private static final String P_CARD_NO = "CardNo";
	private static final String P_TOKEN = "Token";
	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_MEMBER_ID = "MemberID";
	private static final String P_SEQ_MODE = "SeqMode";
	private static final String P_CARD_SEQ = "CardSeq";
	private static final String P_SEARCH_MODE = "SearchMode";
	private static final String P_DELETE_FLAG = "DeleteFlag";

	public void doGet(HttpServletRequest req, HttpServletResponse res)
		throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
		throws ServletException, IOException {

		req.setCharacterEncoding("windows-31j");
		res.setContentType("text/html; charset=windows-31j");
		PrintWriter out = res.getWriter();

		PaymentClientImpl client = new PaymentClientImpl();
		SearchCardReverseInput input = new SearchCardReverseInput();
		SearchCardReverseOutput output = null;

		// パラメータの設定
		input.setSiteId(req.getParameter(P_SITE_ID));
		input.setSitePass(req.getParameter(P_SITE_PASS));
		input.setCardNo(req.getParameter(P_CARD_NO));
		input.setToken(req.getParameter(P_TOKEN));
		input.setShopId(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setOrderId(req.getParameter(P_ORDER_ID));
		input.setMemberId(req.getParameter(P_MEMBER_ID));
		input.setSeqMode(req.getParameter(P_SEQ_MODE));
		input.setCardSeq(req.getParameter(P_CARD_SEQ));
		input.setSearchMode(req.getParameter(P_SEARCH_MODE));
		input.setDeleteFlag(req.getParameter(P_DELETE_FLAG));

		print(out, "INPUT: {0}",
				input.toDataString(false));

		try {
			// API呼び出し
			output = client.doSearchCardReverse(input);
		} catch (PaymentException e) {
			//
			// [注意事項]
			// エラーが発生した場合は、お手数ですが加盟店様側でエラー処理を行っていただくようお願い致します。
			//
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {

			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, MessageFormat.format("ErrorCode: {0}  ErrorInfo: {1}",
								new Object[]{eh.getErrCode(), eh.getErrInfo()}));
			}
		} else {
			List list = output.getCardList();
			print(out, "OUTPUT:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				MemberCardInfo info = (MemberCardInfo)it.next();
		        print(out, "MemberID: {0}", info.getMemberId());
		        print(out, "CreateDate: {0}", info.getCreateDate());
		        print(out, "DeleteFlag: {0}", info.getDeleteFlag());
		        print(out, "----------");
			}
		}
		out.flush();
}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}