package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.SearchCardInput;
import com.gmo_pg.g_pay.client.output.ErrHolder;
import com.gmo_pg.g_pay.client.output.SearchCardOutput;
import com.gmo_pg.g_pay.client.output.SearchCardOutput.CardInfo;

/**
 * カード照会呼び出しサーブレットサンプルクラス
 */
public class CallSearchCardServlet extends HttpServlet {

	private static final String P_SITE_ID = "SiteID";
	private static final String P_SITE_PASS = "SitePass";
	private static final String P_MEMBER_ID = "MemberID";
	private static final String P_CARD_SEQ = "CardSeq";
	private static final String P_SEQ_MODE = "SeqMode";
	private static final String P_VALID_FLAG = "ValidFlag";
	private static final String P_USE_FLOATING_MASK = "useFloatingMask";

	public void doGet(HttpServletRequest req, HttpServletResponse res)
		throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
		throws ServletException, IOException {

		req.setCharacterEncoding("windows-31j");
		res.setContentType("text/html; charset=windows-31j");
		PrintWriter out = res.getWriter();

		PaymentClientImpl client = new PaymentClientImpl();
		SearchCardInput input = new SearchCardInput();
		SearchCardOutput output = null;

		// パラメータの設定
		input.setSiteId(req.getParameter(P_SITE_ID));
		input.setSitePass(req.getParameter(P_SITE_PASS));
		input.setMemberId(req.getParameter(P_MEMBER_ID));
		input.setSeqMode(req.getParameter(P_SEQ_MODE));
		input.setValidFlag(req.getParameter(P_VALID_FLAG));
		input.setUseFloatingMask(req.getParameter(P_USE_FLOATING_MASK));

		if (req.getParameter(P_CARD_SEQ) != null) {

			if ("".equals(req.getParameter(P_CARD_SEQ))) {
				input.setCardSeq(null);
			} else {
				input.setCardSeq(Integer.valueOf(req.getParameter(P_CARD_SEQ)));
			}
		}
		print(out, "INPUT: {0}",
				input.toDataString(false));

		try {
			// API呼び出し
			output = client.doSearchCard(input);
		} catch (PaymentException e) {
			//
			// [注意事項]
			// エラーが発生した場合は、お手数ですが加盟店様側でエラー処理を行っていただくようお願い致します。
			//
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {

			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, MessageFormat.format("ErrorCode: {0}  ErrorInfo: {1}",
								new Object[]{eh.getErrCode(), eh.getErrInfo()}));
			}
		} else {
			List list = output.getCardList();
			print(out, "OUTPUT:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				CardInfo info = (CardInfo)it.next();
		        print(out, "CardSeq: {0}", info.getCardSeq());
		        print(out, "DefaultFlag: {0}", info.getDefaultFlag());
		        print(out, "CardName: {0}", info.getCardName());
		        print(out, "CardNo: {0}", info.getCardNo());
		        print(out, "Expire: {0}", info.getExpire());
		        print(out, "HolderName: {0}", info.getHolderName());
		        print(out, "Brand: {0}", info.getBrand());
		        print(out, "DomesticFlag: {0}", info.getDomesticFlag());
		        print(out, "IssuerCode: {0}", info.getIssuerCode());
		        print(out, "DebitPrepaidFlag: {0}", info.getDebitPrepaidFlag());
		        print(out, "DebitPrepaidIssuerName: {0}", info.getDebitPrepaidIssuerName());
		        print(out, "ForwardFinal: {0}", info.getForwardFinal());
		        print(out, "----------");
			}
		}
		out.flush();
}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}