package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.SearchChargeStatusInput;
import com.gmo_pg.g_pay.client.output.SearchChargeStatusOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * PGプリカチャージ状態照会呼出サーブレットサンプルクラス
 */
public class CallSearchChargeStatusServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ORDER_ID = "OrderID";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        SearchChargeStatusInput input = new SearchChargeStatusInput();
        SearchChargeStatusOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setOrderID(req.getParameter(P_ORDER_ID));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doSearchChargeStatus(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "AccessID: {0}", output.getAccessID());
			print(out, "AccessPass: {0}", output.getAccessPass());
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "Status: {0}", output.getStatus());
			print(out, "Amount: {0}", output.getAmount());
			print(out, "TranDate: {0}", output.getTranDate());
			print(out, "PrecaNo: {0}", output.getPrecaNo());
			print(out, "PrecaSeq: {0}", output.getPrecaSeq());
			print(out, "ExpireDate: {0}", output.getExpireDate());
			print(out, "ChargeType: {0}", output.getChargeType());
			print(out, "Forward: {0}", output.getForward());
			print(out, "Approve: {0}", output.getApprove());
			print(out, "CvsCode: {0}", output.getCvsCode());
			print(out, "CvsConfNo: {0}", output.getCvsConfNo());
			print(out, "CvsReceiptNo: {0}", output.getCvsReceiptNo());
			print(out, "PaymentTerm: {0}", output.getPaymentTerm());
			print(out, "ReceiptURL: {0}", output.getReceiptURL());
			print(out, "CustID: {0}", output.getCustID());
			print(out, "BkCode: {0}", output.getBkCode());
			print(out, "ConfNo: {0}", output.getConfNo());
			print(out, "PayeasyPaymentURL: {0}", output.getPayeasyPaymentURL());
			print(out, "FinishDate: {0}", output.getFinishDate());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
