package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.SearchMemberInput;
import com.gmo_pg.g_pay.client.output.ErrHolder;
import com.gmo_pg.g_pay.client.output.SearchMemberOutput;
import com.gmo_pg.g_pay.client.output.SearchMemberOutput.MemberInfo;

/**
 * 会員照会呼び出しサーブレットサンプルクラス
 */
public class CallSearchMemberServlet extends HttpServlet {

	private static final String P_SITE_ID = "SiteID";
	private static final String P_SITE_PASS = "SitePass";
	private static final String P_MEMBER_ID = "MemberID";

	public void doGet(HttpServletRequest req, HttpServletResponse res)
		throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
		throws ServletException, IOException {

		req.setCharacterEncoding("windows-31j");
		res.setContentType("text/html; charset=windows-31j");
		PrintWriter out = res.getWriter();

		PaymentClientImpl client = new PaymentClientImpl();
		SearchMemberInput input = new SearchMemberInput();
		SearchMemberOutput output = null;

		// パラメータの設定
		input.setSiteId(req.getParameter(P_SITE_ID));
		input.setSitePass(req.getParameter(P_SITE_PASS));
		input.setMemberId(req.getParameter(P_MEMBER_ID));
		print(out, "INPUT: {0}",
				input.toDataString(false));

		try {
			// API呼び出し
			output = client.doSearchMember(input);
		} catch (PaymentException e) {
			//
			// [注意事項]
			// エラーが発生した場合は、お手数ですが加盟店様側でエラー処理を行っていただくようお願い致します。
			//
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {

			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, MessageFormat.format("ErrorCode: {0}  ErrorInfo: {1}",
								new Object[]{eh.getErrCode(), eh.getErrInfo()}));
			}
		} else {
			List list = output.getMemberList();
			print(out, "OUTPUT:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				MemberInfo info = (MemberInfo)it.next();
		        print(out, "MemberID: {0}", info.getMemberId());
		        print(out, "MemberName: {0}", info.getMemberName());
		        print(out, "----------");
			}
		}
		out.flush();
}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}