package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.SearchPrecaHistoryInput;
import com.gmo_pg.g_pay.client.output.SearchPrecaHistoryOutput;
import com.gmo_pg.g_pay.client.output.SearchPrecaHistoryOutput.SearchPrecaHistoryInfo;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * PGプリカPGプリカ履歴照会呼出サーブレットサンプルクラス
 */
public class CallSearchPrecaHistoryServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_PRECA_NO = "PrecaNo";
	private static final String P_PRECA_PASS = "PrecaPass";
	private static final String P_SEARCH_TYPE = "SearchType";
	private static final String P_DAY = "Day";
	private static final String P_MONTH = "Month";
	private static final String P_PRECA_SEQ = "PrecaSeq";
	private static final String P_PROCESS_TYPE = "ProcessType";
	private static final String P_OFFSET = "Offset";
	private static final String P_LIMIT = "Limit";
	private static final String P_CLIENT_FIELD_FLAG = "ClientFieldFlag";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        SearchPrecaHistoryInput input = new SearchPrecaHistoryInput();
        SearchPrecaHistoryOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setPrecaNo(req.getParameter(P_PRECA_NO));
		input.setPrecaPass(req.getParameter(P_PRECA_PASS));
		input.setSearchType(req.getParameter(P_SEARCH_TYPE));
		input.setDay(req.getParameter(P_DAY));
		input.setMonth(req.getParameter(P_MONTH));
		input.setPrecaSeq(
				req.getParameter(P_PRECA_SEQ) == null || req.getParameter(P_PRECA_SEQ).length() == 0
					? null : new Integer(req.getParameter(P_PRECA_SEQ)));

		input.setProcessType(req.getParameter(P_PROCESS_TYPE));
		input.setOffset(
				req.getParameter(P_OFFSET) == null || req.getParameter(P_OFFSET).length() == 0
					? null : new Integer(req.getParameter(P_OFFSET)));

		input.setLimit(
				req.getParameter(P_LIMIT) == null || req.getParameter(P_LIMIT).length() == 0
					? null : new Integer(req.getParameter(P_LIMIT)));

		input.setClientFieldFlag(req.getParameter(P_CLIENT_FIELD_FLAG));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doSearchPrecaHistory(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "PrecaNo: {0}", output.getPrecaNo());
			print(out, "TotalValue: {0}", output.getTotalValue());
			print(out, "Cnt: {0}", output.getCnt());
			print(out, "----------");

			List list = output.getSearchPrecaHistoryList();
			for (Iterator it = list.iterator(); it.hasNext();) {
				SearchPrecaHistoryInfo info = (SearchPrecaHistoryInfo)it.next();
				print(out, "PrecaSeq: {0}", info.getPrecaSeq());
				print(out, "ProcessDate: {0}", info.getProcessDate());
				print(out, "ProcessType: {0}", info.getProcessType());
				print(out, "Value: {0}", info.getValue());
				print(out, "ValidValue: {0}", info.getValidValue());
				print(out, "ExpireDate: {0}", info.getExpireDate());
				print(out, "TargetPrecaSeq: {0}", info.getTargetPrecaSeq());
				print(out, "ClientField: {0}", info.getClientField());
				print(out, "----------");
			}
		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
