package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.SearchTradeDocomoMiniInput;
import com.gmo_pg.g_pay.client.output.SearchTradeDocomoMiniOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * d払い(ミニアプリ)取引状態参照呼出サーブレットサンプルクラス
 */
public class CallSearchTradeDocomoMiniServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ORDER_ID = "OrderID";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        SearchTradeDocomoMiniInput input = new SearchTradeDocomoMiniInput();
        SearchTradeDocomoMiniOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setOrderID(req.getParameter(P_ORDER_ID));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doSearchTradeDocomoMini(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "Status: {0}", output.getStatus());
			print(out, "ProcessDate: {0}", output.getProcessDate());
			print(out, "JobCd: {0}", output.getJobCd());
			print(out, "AccessID: {0}", output.getAccessID());
			print(out, "AccessPass: {0}", output.getAccessPass());
			print(out, "Amount: {0}", output.getAmount());
			print(out, "Tax: {0}", output.getTax());
			print(out, "CancelAmount: {0}", output.getCancelAmount());
			print(out, "CancelTax: {0}", output.getCancelTax());
			print(out, "IncreaseAmount: {0}", output.getIncreaseAmount());
			print(out, "IncreaseTax: {0}", output.getIncreaseTax());
			print(out, "ClientField1: {0}", output.getClientField1());
			print(out, "ClientField2: {0}", output.getClientField2());
			print(out, "ClientField3: {0}", output.getClientField3());
			print(out, "PayType: {0}", output.getPayType());
			print(out, "DocomoStoreOrderNumber: {0}", output.getDocomoStoreOrderNumber());
			print(out, "DocomoSettlementNumber: {0}", output.getDocomoSettlementNumber());
			print(out, "DocomoDisp1: {0}", output.getDocomoDisp1());
			print(out, "DocomoDisp2: {0}", output.getDocomoDisp2());
			print(out, "DocomoToken: {0}", output.getDocomoToken());
			print(out, "DocomoTokenLimitDate: {0}", output.getDocomoTokenLimitDate());
			print(out, "DocomoProcessLimitDate: {0}", output.getDocomoProcessLimitDate());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
