package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.SearchTradeRakutenpayInput;
import com.gmo_pg.g_pay.client.output.SearchTradeRakutenpayOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * 楽天ペイ取引情報照会呼出サーブレットサンプルクラス
 */
public class CallSearchTradeRakutenpayServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ORDER_ID = "OrderID";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        SearchTradeRakutenpayInput input = new SearchTradeRakutenpayInput();
        SearchTradeRakutenpayOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setOrderID(req.getParameter(P_ORDER_ID));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doSearchTradeRakutenpay(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "Status: {0}", output.getStatus());
			print(out, "ProcessDate: {0}", output.getProcessDate());
			print(out, "JobCd: {0}", output.getJobCd());
			print(out, "AccessID: {0}", output.getAccessID());
			print(out, "AccessPass: {0}", output.getAccessPass());
			print(out, "Amount: {0}", output.getAmount());
			print(out, "Tax: {0}", output.getTax());
			print(out, "ClientField1: {0}", output.getClientField1());
			print(out, "ClientField2: {0}", output.getClientField2());
			print(out, "ClientField3: {0}", output.getClientField3());
			print(out, "PayType: {0}", output.getPayType());
			print(out, "RakutenChargeID: {0}", output.getRakutenChargeID());
			print(out, "ReauthLimitDate: {0}", output.getReauthLimitDate());
			print(out, "SalesLimitDate: {0}", output.getSalesLimitDate());
			print(out, "ChangeLimitDate: {0}", output.getChangeLimitDate());
			print(out, "CancelLimitDate: {0}", output.getCancelLimitDate());
			print(out, "RakutenPoint: {0}", output.getRakutenPoint());
			print(out, "RakutenSubscriptionType: {0}", output.getRakutenSubscriptionType());
			print(out, "RakutenSubscriptionID: {0}", output.getRakutenSubscriptionID());
			print(out, "RakutenSettlementSubscriptionID: {0}", output.getRakutenSettlementSubscriptionID());
			print(out, "RakutenSubscriptionCurrentStatus: {0}", output.getRakutenSubscriptionCurrentStatus());
			print(out, "RakutenSubscriptionStartDate: {0}", output.getRakutenSubscriptionStartDate());
			print(out, "RakutenSubscriptionAmount: {0}", output.getRakutenSubscriptionAmount());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
