package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.JobCode;
import com.gmo_pg.g_pay.client.common.Method;
import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.SearchTradeInput;
import com.gmo_pg.g_pay.client.output.ErrHolder;
import com.gmo_pg.g_pay.client.output.SearchTradeOutput;

/**
 * 取引状態照会呼び出しサーブレットサンプルクラス
 */
public class CallSearchTradeServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_ORDER_ID = "OrderID";
	private static final String P_USE_SITE_MASK_LEVEL = "UseSiteMaskLevel";
	private static final String P_USE_FLOATING_MASK = "useFloatingMask";

	public void doGet(HttpServletRequest req, HttpServletResponse res)
		throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
		throws ServletException, IOException {

		req.setCharacterEncoding("windows-31j");
		res.setContentType("text/html; charset=windows-31j");
		PrintWriter out = res.getWriter();

		PaymentClientImpl client = new PaymentClientImpl();
		SearchTradeInput input = new SearchTradeInput();
		SearchTradeOutput output = null;

		// パラメータの設定
        input.setShopId(req.getParameter(P_SHOP_ID));
        input.setShopPass(req.getParameter(P_SHOP_PASS));
        input.setOrderId(req.getParameter(P_ORDER_ID));
        input.setUseSiteMaskLevel(req.getParameter(P_USE_SITE_MASK_LEVEL));
		input.setUseFloatingMask(req.getParameter(P_USE_FLOATING_MASK));
		print(out, "INPUT: {0}",
				input.toDataString(false));

		try {
			// API呼び出し
			output = client.doSearchTrade(input);
		} catch (PaymentException e) {
			//
			// [注意事項]
			// エラーが発生した場合は、お手数ですが加盟店様側でエラー処理を行っていただくようお願い致します。
			//
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {

			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, MessageFormat.format("ErrorCode: {0}  ErrorInfo: {1}",
								new Object[]{eh.getErrCode(), eh.getErrInfo()}));
			}
		} else {
			print(out, "OUTPUT:");
            print(out, "OrderID: {0}", output.getOrderId());
            print(out, "Status: {0}", output.getStatus());
            print(out, "ProcessDate: {0}", output.getProcessDate());
            print(out, "JobCd: {0}", output.getJobCd());
	        print(out, "AccessID: {0}", output.getAccessId());
	        print(out, "AccessPass: {0}", output.getAccessPass());
            print(out, "ItemCode: {0}", output.getItemCode());
            print(out, "Amount: {0}", output.getAmount());
            print(out, "Tax: {0}", output.getTax());
            print(out, "SiteID: {0}", output.getSiteId());
            print(out, "MemberID: {0}", output.getMemberId());
            print(out, "CardNo: {0}", output.getCardNo());
            print(out, "Expire: {0}", output.getExpire());
            print(out, "Method: {0}", output.getMethod());
            print(out, "PayTimes: {0}", output.getPayTimes());
	        print(out, "Forward: {0}", output.getForward());
            print(out, "TranID: {0}", output.getTranId());
	        print(out, "Approve: {0}", output.getApprove());
            print(out, "ClientField1: {0}", output.getClientField1());
            print(out, "ClientField2: {0}", output.getClientField2());
            print(out, "ClientField3: {0}", output.getClientField3());
		}
		out.flush();
}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}