package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.output.ErrHolder;
import com.gmo_pg.g_pay.client.output.SecureTranOutput;

/**
 * 認証決済呼出サーブレットサンプルクラス<br />
 * paresとmdを指定して処理します
 */
public class CallSecurePaResMdTranServlet extends HttpServlet {

	private static final String P_PA_RES = "PaRes";
	private static final String P_MD = "MD";

	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {

		req.setCharacterEncoding("windows-31j");
		res.setContentType("text/html; charset=windows-31j");
		PrintWriter out = res.getWriter();

		PaymentClientImpl client = new PaymentClientImpl();
		SecureTranOutput output = null;

		// パラメータの設定
		String paRes = req.getParameter(P_PA_RES);
		String md = req.getParameter(P_MD);
		print(out, "PaRes: {0}, MD: {1}", new Object[]{paRes, md});

		try {
			// API呼び出し
			output = client.doSecureTran(paRes, md);
		} catch (PaymentException e) {
			//
			// [注意事項]
			// エラーが発生した場合は、お手数ですが加盟店様側でエラー処理を行っていただくようお願い致します。
			//
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {

			List list = output.getErrList();
			print(out, "ERROR:");
			for (Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder) it.next();
				print(out, MessageFormat.format(
						"ErrorCode: {0}  ErrorInfo: {1}", new Object[] {
								eh.getErrCode(), eh.getErrInfo() }));
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "OrderID: {0}", output.getOrderId());
			print(out, "Forward: {0}", output.getForward());
			print(out, "Method: {0}", output.getMethod());
			print(out, "PayTimes: {0}", output.getPayTimes());
			print(out, "Approve: {0}", output.getApprove());
			print(out, "TranID: {0}", output.getTranId());
			print(out, "TranDate: {0}", output.getTranDate());
			print(out, "CheckString: {0}", output.getCheckString());
			print(out, "ClientField1: {0}", output.getClientField1());
			print(out, "ClientField2: {0}", output.getClientField2());
			print(out, "ClientField3: {0}", output.getClientField3());
		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[] { obj });
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt, obj));
		out.print(MessageFormat.format(fmt, obj));
		out.print("<br>");
		out.println();
	}
}