package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.SecureTranDccInput;
import com.gmo_pg.g_pay.client.output.SecureTranDccOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * 多通貨クレジット決済（DCC)認証後決済実行呼出サーブレットサンプルクラス
 */
public class CallSecureTranDccServlet extends HttpServlet {

	private static final String P_PA_RES = "PaRes";
	private static final String P_MD = "MD";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        SecureTranDccInput input = new SecureTranDccInput();
        SecureTranDccOutput output = null;

        // パラメータの設定
		input.setPaRes(req.getParameter(P_PA_RES));
		input.setMD(req.getParameter(P_MD));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doSecureTranDcc(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "Method: {0}", output.getMethod());
			print(out, "DccTranID: {0}", output.getDccTranID());
			print(out, "TranDate: {0}", output.getTranDate());
			print(out, "CheckString: {0}", output.getCheckString());
			print(out, "DccCurrency: {0}", output.getDccCurrency());
			print(out, "DccAmount: {0}", output.getDccAmount());
			print(out, "DccRate: {0}", output.getDccRate());
			print(out, "Ftn: {0}", output.getFtn());
			print(out, "ClientField1: {0}", output.getClientField1());
			print(out, "ClientField2: {0}", output.getClientField2());
			print(out, "ClientField3: {0}", output.getClientField3());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
