package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.SiftScoreInput;
import com.gmo_pg.g_pay.client.output.SiftScoreOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * siftスコア照会呼出サーブレットサンプルクラス
 */
public class CallSiftScoreServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_SIFT_ORDER_ID = "SiftOrderID";
	private static final String P_ORDER_ID = "OrderID";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        SiftScoreInput input = new SiftScoreInput();
        SiftScoreOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setSiftOrderID(req.getParameter(P_SIFT_ORDER_ID));
		input.setOrderID(req.getParameter(P_ORDER_ID));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doSiftScore(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "SiftOrderID: {0}", output.getSiftOrderID());
			print(out, "Type: {0}", output.getType());
			print(out, "ProcessDate: {0}", output.getProcessDate());
			print(out, "UserId: {0}", output.getUserId());
			print(out, "SessionId: {0}", output.getSessionId());
			print(out, "TransactionId: {0}", output.getTransactionId());
			print(out, "Status: {0}", output.getStatus());
			print(out, "OrderID: {0}", output.getOrderID());
			print(out, "PayType: {0}", output.getPayType());
			print(out, "PaymentAbuseScore: {0}", output.getPaymentAbuseScore());
			print(out, "ClientField1: {0}", output.getClientField1());
			print(out, "ClientField2: {0}", output.getClientField2());
			print(out, "ClientField3: {0}", output.getClientField3());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
