package com.gmo_pg.g_pay.client.sample.call;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.gmo_pg.g_pay.client.common.PaymentException;
import com.gmo_pg.g_pay.client.impl.PaymentClientImpl;
import com.gmo_pg.g_pay.client.input.UseCancelInput;
import com.gmo_pg.g_pay.client.output.UseCancelOutput;
import com.gmo_pg.g_pay.client.output.ErrHolder;



/**
 * PGプリカバリュー利用キャンセル呼出サーブレットサンプルクラス
 */
public class CallUseCancelServlet extends HttpServlet {

	private static final String P_SHOP_ID = "ShopID";
	private static final String P_SHOP_PASS = "ShopPass";
	private static final String P_PRECA_NO = "PrecaNo";
	private static final String P_PRECA_PASS = "PrecaPass";
	private static final String P_PRECA_SEQ = "PrecaSeq";
	private static final String P_CLIENT_FIELD = "ClientField";


	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
    	throws ServletException, IOException {

        req.setCharacterEncoding("windows-31j");
        res.setContentType("text/html; charset=windows-31j");
        PrintWriter out = res.getWriter();

        PaymentClientImpl client = new PaymentClientImpl();
        UseCancelInput input = new UseCancelInput();
        UseCancelOutput output = null;

        // パラメータの設定
		input.setShopID(req.getParameter(P_SHOP_ID));
		input.setShopPass(req.getParameter(P_SHOP_PASS));
		input.setPrecaNo(req.getParameter(P_PRECA_NO));
		input.setPrecaPass(req.getParameter(P_PRECA_PASS));
		input.setPrecaSeq(
				req.getParameter(P_PRECA_SEQ) == null || req.getParameter(P_PRECA_SEQ).length() == 0
					? null : new Integer(req.getParameter(P_PRECA_SEQ)));

		input.setClientField(req.getParameter(P_CLIENT_FIELD));

       	print(out, "INPUT: {0}", input.toDataString(false));

		try {
			// API呼び出し
			output = client.doUseCancel(input);
		} catch (PaymentException e) {
			e.printStackTrace();
			throw new ServletException(e);
		}

		// 結果確認
		if (output.isErrorOccurred()) {
			List list = output.getErrList();
			print(out, "ERROR:");
			for(Iterator it = list.iterator(); it.hasNext();) {
				ErrHolder eh = (ErrHolder)it.next();
				print(out, "ErrorCode: {0}  ErrorInfo: {1}",
						new Object[]{eh.getErrCode(), eh.getErrInfo()});
			}
		} else {
			print(out, "OUTPUT:");
			print(out, "PrecaNo: {0}", output.getPrecaNo());
			print(out, "PrecaSeq: {0}", output.getPrecaSeq());
			print(out, "ProcessDate: {0}", output.getProcessDate());
			print(out, "TotalValue: {0}", output.getTotalValue());

		}
		out.flush();
	}

	private void print(PrintWriter out, String str) {
		print(out, str, null);
	}

	private void print(PrintWriter out, String fmt, Object obj) {
		print(out, fmt, new Object[]{obj});
	}

	private void print(PrintWriter out, String fmt, Object[] obj) {
		System.out.println(MessageFormat.format(fmt,obj));
		out.print(MessageFormat.format(fmt,obj));
		out.print("<br>");
		out.println();
	}
}
